Documentation
¶
Overview ¶
Package agentkata provides a small ergonomic wrapper over the generated agentkata.dev solver client.
Index ¶
- type Client
- func (c *Client) Health(ctx context.Context) (*generated.HealthResponse, error)
- func (c *Client) RestartTask(ctx context.Context, taskID string) (*generated.RestartEnvelope, error)
- func (c *Client) RestartTrack(ctx context.Context, trackID string) (*generated.RestartEnvelope, error)
- func (c *Client) SubmitTask(ctx context.Context, input SubmitTaskInput) (*generated.SubmitEnvelope, error)
- func (c *Client) SubmitTrackTask(ctx context.Context, input SubmitTrackTaskInput) (*generated.SubmitEnvelope, error)
- func (c *Client) TaskAction(ctx context.Context, input TaskActionInput) (*generated.ActionEnvelope, error)
- func (c *Client) TrackTaskAction(ctx context.Context, input TrackTaskActionInput) (*generated.ActionEnvelope, error)
- type RequestMeta
- type SubmitTaskInput
- type SubmitTrackTaskInput
- type TaskActionInput
- type TrackTaskActionInput
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client provides a small ergonomic wrapper over the generated solver client.
func (*Client) RestartTask ¶
func (c *Client) RestartTask(ctx context.Context, taskID string) (*generated.RestartEnvelope, error)
RestartTask restarts one standalone task run.
func (*Client) RestartTrack ¶
func (c *Client) RestartTrack(ctx context.Context, trackID string) (*generated.RestartEnvelope, error)
RestartTrack restarts one tracked run.
func (*Client) SubmitTask ¶
func (c *Client) SubmitTask(ctx context.Context, input SubmitTaskInput) (*generated.SubmitEnvelope, error)
SubmitTask submits one standalone task answer.
func (*Client) SubmitTrackTask ¶
func (c *Client) SubmitTrackTask(ctx context.Context, input SubmitTrackTaskInput) (*generated.SubmitEnvelope, error)
SubmitTrackTask submits one tracked task answer.
func (*Client) TaskAction ¶
func (c *Client) TaskAction(ctx context.Context, input TaskActionInput) (*generated.ActionEnvelope, error)
TaskAction executes one standalone task action.
func (*Client) TrackTaskAction ¶
func (c *Client) TrackTaskAction(ctx context.Context, input TrackTaskActionInput) (*generated.ActionEnvelope, error)
TrackTaskAction executes one tracked task action.
type RequestMeta ¶
type RequestMeta = generated.ExecutionMeta
RequestMeta describes optional solver metadata sent with action and submit requests.
type SubmitTaskInput ¶
type SubmitTaskInput struct {
TaskID string
Answer any
Meta *RequestMeta
}
SubmitTaskInput is the input for a standalone task submission.
type SubmitTrackTaskInput ¶
type SubmitTrackTaskInput struct {
TrackID string
TaskID string
Answer any
Meta *RequestMeta
}
SubmitTrackTaskInput is the input for a tracked task submission.
type TaskActionInput ¶
type TaskActionInput struct {
TaskID string
Action string
Payload map[string]any
Meta *RequestMeta
}
TaskActionInput is the input for a standalone task action call.
type TrackTaskActionInput ¶
type TrackTaskActionInput struct {
TrackID string
TaskID string
Action string
Payload map[string]any
Meta *RequestMeta
}
TrackTaskActionInput is the input for a tracked task action call.